pub fn classify_content_role(
element_type: &str,
actions: &[String],
state: &ElementState,
) -> ContentRoleExpand description
Classify an element’s content role based on its type and properties.
pub fn classify_content_role(
element_type: &str,
actions: &[String],
state: &ElementState,
) -> ContentRoleClassify an element’s content role based on its type and properties.